<?php

namespace Classifieds\Classified\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Classifieds\Classified\Actions\ClassifiedAction;
use Classifieds\Classified\Http\Requests\ClassifiedActionRequest;
use Classifieds\Classified\Http\Resources\ClassifiedResource;
use Classifieds\Classified\Models\Classified;

/**
 * Admin web controller class.
 */
class ClassifiedActionController extends BaseController
{

    /**
     * Action controller function for classified.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ClassifiedActionRequest $request, Classified $classified, $action)
    {
        try {
            $request = $request->all();
            $classified = ClassifiedAction::run($action, $classified, $request);

            $data = new ClassifiedResource($classified);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('classified::classified.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('classified/classified/' . $classified->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('classified/classified/' . $classified->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
