<?php

namespace Classifieds\Classified\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Classifieds\Classified\Http\Requests\ClassifiedActionsRequest;
use Classifieds\Classified\Actions\ClassifiedActions;

/**
 * Admin web controller class.
 */
class ClassifiedActionsController extends BaseController
{

    /**
     * Action controller function for classified.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ClassifiedActionsRequest $request, $action)
    {
        try {
            $classified = ClassifiedActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('classified::classified.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('classified/classified/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('classified/classified/' . $action))
                ->redirect();
        }
    }
}
