<?php

namespace Classifieds\Classified\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Classifieds\Classified\Events\ClassifiedAction as ClassifiedActionEvent;
use Classifieds\Classified\Notifications\ClassifiedAction as ClassifiedActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ClassifiedAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ClassifiedActionEvent.
     *
     * @param   ClassifiedActionEvent  $event
     * @return mixed
     */
    public function handle(ClassifiedActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $classified.
     *
     * @param   ClassifiedActionEvent  $event
     * @return void
     */
    public function create(ClassifiedActionEvent $event)
    {
        $client = $event->classified->client;
        Notification::send($client, new ClassifiedActionNotification($event));
    }

    /**
     * Handle the ClassifiedActionEvent as a listener.
     *
     * @param   ClassifiedActionEvent  $event
     * @return mixed
     */
    public function asListener(ClassifiedActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ClassifiedActionEvent  $event
     * @return bool
     */
    private function isAllowed(ClassifiedActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
