<?php

namespace Classifieds\Classified\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Classifieds\Classified\Events\ClassifiedWorkflow as ClassifiedWorkflowEvent;
use Classifieds\Classified\Notifications\ClassifiedWorkflow as ClassifiedWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ClassifiedWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ClassifiedWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $classified is submitted.
     *
     * @param ClassifiedWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ClassifiedWorkflowEvent $event)
    {
        $client = $event->classified->client;
        Notification::send($client, new ClassifiedWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $classified is published.
     *
     * @param ClassifiedWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ClassifiedWorkflowEvent $event)
    {
        $client = $event->classified->client;
        Notification::send($client, new ClassifiedWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $classified is approved.
     *
     * @param ClassifiedWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ClassifiedWorkflowEvent $event)
    {
        $client = $event->classified->client;
        Notification::send($client, new ClassifiedWorkflowNotification($event));
    }

    /**
     * Handles the $classified workflow event as a listener.
     *
     * @param ClassifiedWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ClassifiedWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
