<?php
namespace Classifieds\Classified\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Classifieds\Classified\Events\ClassifiedAction as ClassifiedActionEvent;
use Classifieds\Classified\Models\Classified;

class ClassifiedAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $classified;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ClassifiedActionEvent $classified
     */
    public function __construct(ClassifiedActionEvent $classified)
    {
        $this->action = $event->action;
        $this->classified = $classified;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Classified Approved - ' . config('app.name'))
            ->view('classified::classified.email.action', ['data' => $this->classified]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
