<?php

namespace Classifieds\Classified\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Classifieds\Classified\Models\Classified;

class ClassifiedPolicy
{

    use ClassifiedAction;
    use ClassifiedWorkflow;

    /**
     * Determine if the given user can view the classified.
     *
     * @param Authenticatable $user
     * @param Classified $classified
     *
     * @return bool
     */
    public function view(Authenticatable $user, Classified $classified)
    {
        if ($authUser->canDo('classified.classified.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $classified->is_owner;
    }

    /**
     * Determine if the given user can create a classified.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('classified.classified.create');
    }

    /**
     * Determine if the given user can update the given classified.
     *
     * @param Authenticatable $user
     * @param Classified $classified
     *
     * @return bool
     */
    public function update(Authenticatable $user, Classified $classified)
    {
        if ($user->canDo('classified.classified.edit') && $user->isAdmin()) {
            return true;
        }

        return $classified->is_owner;
    }

    /**
     * Determine if the given user can delete the given classified.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Classified $classified)
    {
        return $classified->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
